# Capitulo: Inflaci??n y desempleo en ciudades de M??xico
# una evaluaci??n con modelos panel y aplicaciones en software R.
# Miguel Angel Mendoza-Gonz??lez, UNAM (2015) 

# Activar librerias, que se instalaron previamente
library(plm) # Para estimar modelos panel (plm=Linear Models for Panel Data)
library(car) # Para estimar modelos de regresi??n (car=companion to applied regresion) 


# Elegir el directorio de trabajo (modificar para su caso particular)
# Nota: en el caso de windows cambiar / por \
setwd("/Volumes/LACIE SHARE/Articulos/Inflacion y Desempleo Regional/Panel_R")

# Lectura de la base de datos
load("InflacionDesempleoCiudades.RData")

# La base de datos del archivo se llama BDatos
summary(BDatos) # Resumen de caracteristicas de la base de datos

View(BDatos) # Visualizar la base de datos 

# Matriz de diagramas de dispersi??n entre variables, con funciones de densidad 
scatterplotMatrix(~INF+U_UN+CETES28, reg.line=lm, smooth=FALSE, spread=FALSE, 
                  span=0.5, diagonal = 'density', data=BDatos)

# Matriz de diagramas de dispersi??n entre variables, con histogramas 
scatterplotMatrix(~INF+U_UN+CETES28, reg.line=lm, smooth=FALSE, spread=FALSE, 
                  span=0.5, diagonal = 'histogram', data=BDatos)

# Modelo pool
modelo.pool <- plm(INF~U_UN+CETES28, data = BDatos, model = "pooling")
summary(modelo.pool) # Resumen de resultados

# Modelo de efectos fijos
modelo.ef <- plm(INF~U_UN+CETES28, data = BDatos, model = "within")
summary(modelo.ef) # Resumen de resultados

# Modelo de efectos aleatorios
modelo.ea <- plm(INF ~ U_UN+CETES28, data = BDatos, model = "random",random.method="amemiya")
summary(modelo.ea) # Resumen de resultados

# Prueba de hipotesis: Modelo de efectos fijos (ef) versus el modelo Pool (pool)
pooltest(modelo.pool, modelo.ef)

# Prueba de hipotesis: Modelo de efectos aleatorios (ea) versus el modelo de efectos fijos (ef)
phtest(modelo.ea, modelo.ef)

